Changes
=======

Version 0.1.3 (released 2015-09-07)

- Adds space between icons and text within buttons. This follows the
  bootstrap design guidelines and makes it more consistent with the
  rest of Invenio.
- Reintegrates permission checks after module rewrite. (#17) (#19)

Version 0.1.2 (released 2015-08-25)

- Adds missing `invenio_upgrader` dependency and amends past upgrade
  recipes following its separation into standalone package.

Version 0.1.1 (released 2015-08-04)

- Removes dependency on Invenio legacy package.

Version 0.1.0 (released 2015-07-31)

- Initial public release.
